@@ -23,8 +23,7 @@ import logging
 import os
 
 
-
-if  __name__ == "__main__" and __package__ is None:
+if __name__ == "__main__" and __package__ is None:
     logging.getLogger().error("You seem to be trying to execute " +
                               "this script directly which is discouraged. " +
                               "Try python -m instead.")
@@ -37,9 +36,9 @@ if  __name__ == "__main__" and __package__ is None:
     __package__ = str('keysign')
 
 from .__init__ import __version__
-from .gpgmh import get_usable_keys, get_public_key_data
+from .gpgmeh import get_usable_keys, get_public_key_data
 from .i18n import _
-from .util import mac_generate
+from .util import mac_generate, format_fingerprint
 from . import Keyserver
 
 log = logging.getLogger(__name__)
@@ -55,7 +54,7 @@ class AvahiHTTPOffer:
         self.mac = mac_generate(fingerprint.encode('ascii'), keydata)
 
     def start(self):
-        "Starts offering the key"
+        """Starts offering the key"""
         fingerprint = self.fingerprint.upper()
         mac = self.mac.upper()
         discovery_info = 'OPENPGP4FPR:{0}#MAC={1}'.format(
@@ -64,7 +63,7 @@ class AvahiHTTPOffer:
         log.info("Requesting to start")
         self.keyserver.start()
 
-        return discovery_info
+        return format_fingerprint(self.key.fingerprint), discovery_info
 
     def stop(self):
         "Stops offering the key"
@@ -87,6 +86,7 @@ def main(args):
     input_("Press Enter to stop")
     offer.stop()
 
+
 if __name__ == "__main__":
     import sys
     main(sys.argv[1:])
